This function aims to help users install GNU MCSim more easily.
However, if you can not install it through this function.
The additional way is to follow the instruction and install it manually:
https://www.gnu.org/software/mcsim/mcsim.html#Installation
The default mxstp is setting to 5000.
The user can increase mxstp to avoid possible error return.
If you meet any error when conduct sensitivity analysis,
you can this function to reinstall GNU MCSim and set the higher mxstp.
The default installed directory is under /home/username (Linux),
/Users/username (MacOS),
and C:/Users/ (windows). To install GNU MCSim in Windows, be sure to install Rtools first.